@@ -38,11 +38,14 @@
 #endif
 
 /* RTLD_NOW is the preferred symbol resolution behavior, but
-   some platforms do not support it. */
+ * some platforms do not support it. 
+ *
+ * ALSA requires RTLD_GLOBAL.
+ */
 #if defined(__OpenBSD__)	
-#define DLOPEN_FLAG RTLD_LAZY
+#define DLOPEN_FLAG (RTLD_LAZY)
 #else
-#define DLOPEN_FLAG RTLD_NOW
+#define DLOPEN_FLAG (RTLD_NOW | RTLD_GLOBAL)
 #endif
 
 /* --- Constants --- */
